@@ -20,8 +20,8 @@ def handle(data, secrets, function_call_info):
          output = dict(status='ok')
       cdf.api_keys = secrets
       cdf.set_up_cdf_client(context='deploy')
-      metadata = cdf.get_function_metadata(function_call_info["function_id"])
-      output.update(dict(metadata=metadata))
+      function_call_metadata = cdf.get_function_call_response_metadata(function_call_info["function_id"])
+      output.update(dict(metadata=function_call_metadata))
       return output
    except Exception:
       trace = traceback.format_exc()
