@@ -68,7 +68,7 @@ def deploy_model(model_settings, platform_methods=platform_methods):
         else:
             logging.warning("Model test file is missing! Didn't run tests")
 
-        if c.platform == "cdf": # For now this will always be the case. #TODO:  
+        if c.platform == "cdf": # For now this will always be the case
             if len(splitted_external_id := function_name.split("-")) > 3: 
                 latest_model_version = splitted_external_id[-1]
                 env = splitted_external_id[-2]
@@ -78,8 +78,6 @@ def deploy_model(model_settings, platform_methods=platform_methods):
 
             artifact_external_id = model_name + "/" + env 
             artifact_versions = cdf.query_file_versions(directory_prefix="/mlops", external_id_prefix=artifact_external_id)
-            if len(artifact_versions) == 0:
-                return f"Model {human_readable_function_name} failed to deploy to {env} because no artifacts were found. Please upload/promote artifacts or specify a correct model name and redeploy"
             latest_artifact_version = artifact_versions.loc[artifact_versions.uploadedTime.argmax()].metadata["version"]
             logging.info(f"Latest artifact version in {env} environment is {latest_artifact_version}")
             external_id = function_name + "-" + str(latest_artifact_version)
