@@ -113,29 +113,38 @@ def find_model_version(model_name, env, metadata):
     )
 
     if (n_models := file_list.shape[0]) == 0:
-        message = f"No model found with {model_name=} in {env=} and {metadata}"
+        message = f"No model artifacts found for model with {model_name=} in {env=} and metadata {metadata}. Upload/promote artifacts or specify the correct model name before redeploying"
         raise Exception(message)
     elif n_models > 1:
-        logging.debug(f"Found {n_models} model files. Will choose the latest.")
+        logging.debug(f"Found {n_models} model artifact folders, deploy using the latest")
     
     # Get latest in case there are more than one
     external_id = file_list.loc[file_list.uploadedTime.argmax(), "externalId"]
     return external_id
 
 
-def download_model_version(model_name, env, folder, metadata={}):
+def download_model_version(model_name, env, folder, metadata={}, version=None):
     """
-    Download a model version to a folder. First the model's external id is
-    found, and then it is downloaded to the chosen folder (creating the folder
-    if necessary).
+    Download a model version to a folder. First the model's external id is found
+    (unless provided by the user), and then it is downloaded to the chosen
+    folder (creating the folder if necessary).
 
     Input: 
         -model_name: name of the model 
         -env: name of the environment ('dev', 'test', 'prod')
-        -folder: (Path) path to folder where the content will be uploaded
-        -metadata: query to the metadata (dictionary)
+        -folder: (Path or str) path to folder where the content will be uploaded
+        -metadata: query to the metadata (dictionary), doesn't make sense when
+            passing a version (see next parameter)
+        -version: (int, optional) if given, this is the version to download
     """
-    external_id = find_model_version(model_name, env, metadata)
+    if isinstance(folder, str):
+        folder = Path(folder)
+    
+    if version:
+        external_id = f"{model_name}/{env}/{version}"
+    else:
+        external_id = find_model_version(model_name, env, metadata)
+
     if not folder.exists():
         folder.mkdir()
     cdf.download_folder(external_id, folder)
